emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

master 204d9f976d 2/4: Make dictionary-help obsolete in favor of describ


From: Stefan Kangas
Subject: master 204d9f976d 2/4: Make dictionary-help obsolete in favor of describe-mode
Date: Thu, 21 Jul 2022 03:23:37 -0400 (EDT)

branch: master
commit 204d9f976dc4c0f3680bc9ef3392b35701617197
Author: Stefan Kangas <stefan@marxist.se>
Commit: Stefan Kangas <stefan@marxist.se>

    Make dictionary-help obsolete in favor of describe-mode
    
    * lisp/net/dictionary.el (dictionary-help): Make obsolete in favor
    of describe-mode.  Update uses.
---
 lisp/net/dictionary.el | 9 +++++----
 1 file changed, 5 insertions(+), 4 deletions(-)

diff --git a/lisp/net/dictionary.el b/lisp/net/dictionary.el
index d093615019..9143c7d111 100644
--- a/lisp/net/dictionary.el
+++ b/lisp/net/dictionary.el
@@ -330,7 +330,7 @@ is utf-8"
   :doc "Keymap for the dictionary mode."
   :suppress t :parent button-buffer-map
   "q"     #'dictionary-close
-  "h"     #'dictionary-help
+  "h"     #'describe-mode
   "s"     #'dictionary-search
   "d"     #'dictionary-lookup-definition
   "D"     #'dictionary-select-dictionary
@@ -379,7 +379,7 @@ protocol defined in RFC 2229.
 This is a quick reference to this mode describing the default key bindings:
 \\<dictionary-mode-map>
 * \\[dictionary-close] close the dictionary buffer
 * \\[dictionary-help] display this help information
 * \\[dictionary-search] ask for a new word to search
 * \\[dictionary-lookup-definition] search the word at point
 * \\[forward-button] or TAB place point to the next link
@@ -389,7 +389,7 @@ This is a quick reference to this mode describing the 
default key bindings:
 * \\[dictionary-select-dictionary] select the default dictionary
 * \\[dictionary-select-strategy] select the default search strategy
 
-* RET or <mouse-2> visit that link"
+* \\`RET' or \\`<mouse-2>' visit that link"
 
   (unless (eq major-mode 'dictionary-mode)
     (cl-incf dictionary-instances))
@@ -1184,7 +1184,8 @@ allows editing it."
 
 (defun dictionary-help ()
   "Display a little help."
-  (interactive)
+  (declare (obsolete describe-mode "29.1"))
+  (interactive nil dictionary-mode)
   (describe-function 'dictionary-mode))
 
 ;;;###autoload
@@ -379,7 +379,7 @@ protocol defined in RFC 2229.
 \\<dictionary-mode-map>
 * \\[dictionary-close] close the dictionary buffer
-* \\[dictionary-help] display this help information
+* \\[describe-mode] display this help information
 * \\[dictionary-search] ask for a new word to search
 * \\[dictionary-lookup-definition] search the word at point



reply via email to

[Prev in Thread] Current Thread [Next in Thread]